# -*- coding: utf-8 -*-
#
# Copyright (C) 2006-2007 Edgewall Software
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at http://posterity.edgewall.org/wiki/License.
#
# This software consists of voluntary contributions made by many
# individuals. For the exact contribution history, see the revision
# history and logs, available at http://posterity.edgewall.org/log/.

from elixir import objectstore

from posterity.admin.admin import run_admin
from posterity.model import Account, Tag
from posterity.tests.fixtures import PosterityTestApp

def setup_module():
    global app
    app = PosterityTestApp()

def teardown_module():
    app.teardown_instance()

def test_create_pop3account():
    app.login('testuser')
    resp = app.get('/tags/Inbox/convs')
    resp = resp.click('Settings').click('POP3 Accounts')
    form = resp.forms['create-pop3account']
    form.set('hostname', 'incorrect.example.com')
    form.set('username', 'foo')
    form.set('password', 'incorrect')
    resp = form.submit()
    resp.mustcontain('Connection test failed:')
    form = resp.forms['create-pop3account']
    form.set('hostname', 'fake-pop3.example.com')
    form.set('password', 'incorrect')
    resp = form.submit()
    resp.mustcontain('Login test failed, check your username and password')
    form = resp.forms['create-pop3account']
    form.set('password', 'bar')
    resp = form.submit().follow()
    resp.mustcontain('fake-pop3.example.com')
    
def test_modify_pop3account():
    resp = app.get('/pop3')
    resp = resp.click('fake-pop3.example.com')
    form = resp.forms['modify-pop3account']
    form.set('hostname', 'fake2-pop3.example.com')
    resp = form.submit().follow()
    resp.mustcontain('fake2-pop3.example.com')
    
def test_delete_pop3account():
    resp = app.get('/pop3')
    resp = resp.click('fake2-pop3.example.com')
    form = resp.forms['delete-pop3account']
    resp = form.submit().follow()
    assert not 'fake2-pop3.example.com' in resp

def test_fetch():
    # Add a tag called 'POP'
    account = Account.get_by(username='testuser')
    tag = Tag(account=account, name='POP')
    # Tag all downloaded messages with a POP tag
    objectstore.flush()
    resp = app.get('/pop3')
    form = resp.forms['create-pop3account']
    form.set('hostname', 'fake.example.com')
    form.set('username', 'foo')
    form.set('password', 'bar')
    form.set('tag', 'POP')
    resp = form.submit().follow()
    # Verify that messages are downloaded and tagged correctly
    assert len(tag.get_convs()) == 0
    run_admin(['posterity-admin', 'fetch', '--once', '-i', app.instance.path])
    convs = tag.get_convs()
    assert len(convs) == 2

